@@ -50,28 +50,24 @@ class Shell(object):
                 if self.__username__:
                     command = 'sudo -u {username} {command}'.format(username=self.__username__, command=command)
                 logger.info(command)
-
-                command = shlex.split(command)
-
-                process = subprocess.Popen(command,
-                    universal_newlines=True,
-                    shell=False,
-                    stdin=subprocess.PIPE,
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE,
-                    bufsize=0,
-                    cwd=self.cwd
-                )
-                out, err = process.communicate()
-                sys.stdout.write(out or err)
-                if raw:
-                    results.append(out)
-                else:
-                    output = not bool(process.wait())
-                    results.append(output)
-
+                results.append(self.execute(command, raw))
             return results[0] if len(results) == 1 else results
 
+    def execute(self, command, raw):
+        command = shlex.split(command)
+        process = subprocess.Popen(command,
+            universal_newlines=True,
+            shell=False,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            bufsize=0,
+            cwd=self.cwd
+        )
+        out, err = process.communicate()
+        logger.info(out or err)
+        return out if raw else not bool(process.wait())
+
     @contextmanager
     def as_user(self, username):
         '''
